@@ -5,6 +5,7 @@ use num_traits::Signed;
 use std::error::Error;
 use std::fmt;
 use std::ops::{Deref, DerefMut, Index, IndexMut, Neg, Range};
+use std::slice::{Iter, IterMut};
 
 /// Matrix of an arbitrary type. Data are stored consecutively in
 /// memory, by rows. Raw data can be accessed using `as_ref()`
@@ -407,6 +408,18 @@ impl<C> Matrix<C> {
         let columns = self.columns;
         (0..self.rows).flat_map(move |r| (0..columns).map(move |c| (r, c)))
     }
+
+    /// Return an iterator on values, first row first.
+    #[must_use]
+    pub fn values(&self) -> Iter<C> {
+        self.data.iter()
+    }
+
+    /// Return a mutable iterator on values, first row first.
+    #[must_use]
+    pub fn values_mut(&mut self) -> IterMut<C> {
+        self.data.iter_mut()
+    }
 }
 
 impl<'a, C> Index<&'a (usize, usize)> for Matrix<C> {
